django_premailer.tests.testapp package
======================================

Submodules
----------

django_premailer.tests.testapp.settings module
----------------------------------------------

.. automodule:: django_premailer.tests.testapp.settings
    :members:
    :undoc-members:
    :show-inheritance:

django_premailer.tests.testapp.urls module
------------------------------------------

.. automodule:: django_premailer.tests.testapp.urls
    :members:
    :undoc-members:
    :show-inheritance:

django_premailer.tests.testapp.views module
-------------------------------------------

.. automodule:: django_premailer.tests.testapp.views
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: django_premailer.tests.testapp
    :members:
    :undoc-members:
    :show-inheritance:
